The [cTuning foundation](https://cTuning.org), [cKnowledge.org](https://cKnowledge.org) and [MLCommons](https://mlcommons.org) 
are preparing an open reproducibility challenge to reproduce various results from the MLPerf inference benchmark v4.1
using the MLCommons CM automation framework. Please stay tuned for more details!

